==> newlife-components-1.4.20.tgz: package/src/index.js <==
//引入工具类
import utils from './utils/index';
//引入项目常量
import * as NfConst from './utils/const/NfConst';
//引入element-ui
import ElementUI from 'element-ui';
//引入element-ui 样式和主题
import '@nftheme/scss/el-themes.scss';
//引入图标库
import 'font-awesome/scss/font-awesome.scss';
//引入状态管理
import Vuex from 'vuex';
import NfStore from "./lib/vuex/index";
//引入路由
import Router from 'vue-router';
import NfRouter from "./lib/router";
//引入http+axios
import NfHttp from './lib/http/index';
//引入组件
import components from "./packages/index";
import Contextmenu from "vue-contextmenujs";
//引入tab页加载器
import NfTabs from "./lib/tab/index";
//引入api
import NfApis from "./lib/apis/index";
//引入Mock
import NfMocks from "./lib/mock";
//引入权限校验
import NfPermission from "./lib/directives/permission";
//安装组件和工具类
//供Vue.use调用
let cfg = {};
const nfConfig = function (config) {
  cfg = config;
};
const install = function (Vue) {
  if (install.installed) {
    return;
  }
  //安装ElementUI实例获取
  Vue.use(ElementUI, {size: 'mini'});
  //安装Contextmenu
  // Vue.use(Contextmenu);
  Contextmenu.install(Vue);
  //安装Vuex
  Vue.use(Vuex);
  //安装store
  Vue.prototype.$nfStore = NfStore.init(cfg.stores);
  //安装Router
  Vue.use(Router);
  Vue.prototype.$nfRouter = NfRouter.init(cfg.routers, Vue);
  //安装http
  Vue.prototype.$nfHttp = NfHttp.init(cfg.httpConfig);
  //遍历安装工具类
  Object.getOwnPropertyNames(utils).forEach(key => {
    Vue.prototype[key] = utils[key];
  });
  // 遍历注册全局组件
  Object.getOwnPropertyNames(components).forEach(key => {
    Vue.component(components[key].name, components[key]);
  });
  //tab页加载器
  Vue.prototype.$nfTabs = NfTabs.init(cfg.tabs, Vue);
  //api加载器
  NfApis.init(cfg.apis, Vue);
  //mock加载
  NfMocks.init(cfg.httpConfig.baseURL, cfg.mocks);
  //client
  Vue.prototype.$client = cfg.client;
  NfConst.OAUTH2_TOKEN.client = cfg.client;
  //安装全局常量
  Vue.prototype.$nfConst = NfConst;
  //安装权限校验器
  NfPermission.install(Vue);
  //socket
  install.installed = true;
};
//供直接引入文件时调用
if (typeof window !== "undefined" && window.Vue) {
  install(window.Vue);
}
export default {
  install, nfConfig
}

==> newlife-components-1.6.0.tgz: package/src/index.js <==
//引入工具类
import utils from './utils/index';
//引入项目常量
import * as NfConst from './utils/const/NfConst';
//引入element-ui
import ElementUI from 'element-ui';
//引入element-ui 样式和主题
import '@nftheme/scss/el-themes.scss';
//引入图标库
import 'font-awesome/scss/font-awesome.scss';
//引入状态管理
import Vuex from 'vuex';
import NfStore from "./lib/vuex/index";
//引入路由
import Router from 'vue-router';
import NfRouter from "./lib/router";
//引入http+axios
import NfHttp from './lib/http/index';
//引入组件
import components from "./packages/index";
import Contextmenu from "vue-contextmenujs";
//引入tab页加载器
import NfTabs from "./lib/tab/index";
//引入api
import NfApis from "./lib/apis/index";
//引入Mock
import NfMocks from "./lib/mock";
//引入权限校验
import NfPermission from "./lib/directives/permission";
//安装组件和工具类
//供Vue.use调用
let cfg = {};
const nfConfig = function (config) {
  cfg = config;
};
const install = function (Vue) {
  if (install.installed) {
    return;
  }
  //安装ElementUI实例获取
  Vue.use(ElementUI, {size: 'mini'});
  //安装Contextmenu
  // Vue.use(Contextmenu);
  Contextmenu.install(Vue);
  //安装Vuex
  Vue.use(Vuex);
  //安装store
  Vue.prototype.$nfStore = NfStore.init(cfg.stores);
  //安装Router
  Vue.use(Router);
  Vue.prototype.$nfRouter = NfRouter.init(cfg.routers, Vue);
  //安装http
  Vue.prototype.$nfHttp = NfHttp.init(cfg.http);
  //遍历安装工具类
  Object.getOwnPropertyNames(utils).forEach(key => {
    Vue.prototype[key] = utils[key];
  });
  // 遍历注册全局组件
  Object.getOwnPropertyNames(components).forEach(key => {
    Vue.component(components[key].name, components[key]);
  });
  //tab页加载器
  Vue.prototype.$nfTabs = NfTabs.init(cfg.tabs, Vue);
  //api加载器
  NfApis.init(cfg.apis, Vue);
  //mock加载
  NfMocks.init(cfg.http.baseURL, cfg.mocks);
  //client
  Vue.prototype.$client = cfg.client.client;
  if(cfg.client.base_url){
    NfConst.CLIENT_INIT.base_url = cfg.client.base_url;
  }
  if(cfg.client.status){
    NfConst.CLIENT_INIT.status = cfg.client.status;
  }
  //安装全局常量
  Vue.prototype.$nfConst = NfConst;
  //安装权限校验器
  NfPermission.install(Vue);
  //socket
  install.installed = true;
};
//供直接引入文件时调用
if (typeof window !== "undefined" && window.Vue) {
  install(window.Vue);
}
export default {
  install, nfConfig
}
